@@ -1,6 +1,6 @@
 undef $VERSION;
 package Bio::Roary::CommandLine::GeneAlignmentFromNucleotides;
-$Bio::Roary::CommandLine::GeneAlignmentFromNucleotides::VERSION = '3.3.1';
+$Bio::Roary::CommandLine::GeneAlignmentFromNucleotides::VERSION = '3.3.2';
 # ABSTRACT: Take in a multifasta file of nucleotides, convert to proteins and align with PRANK
 
 
@@ -22,6 +22,7 @@ has 'nucleotide_fasta_files' => ( is => 'rw', isa => 'ArrayRef' );
 has '_error_message'         => ( is => 'rw', isa => 'Str' );
 has 'verbose'                => ( is => 'rw', isa => 'Bool', default => 0 );
 has 'mafft'                  => ( is => 'rw', isa => 'Bool', default => 0 );
+has '_min_similarity'        => ( is => 'rw', isa => 'Num',  default  => 0.98 );
 
 sub BUILD {
     my ($self) = @_;
@@ -71,7 +72,7 @@ sub run {
         );
         $sort_fasta_before->sort_fasta->replace_input_with_output_file;
 
-        if ( $sort_fasta_before->variation_detected == 1 ) {
+        if ( $sort_fasta_before->sequences_unaligned == 1  || $sort_fasta_before->sequences_unaligned == 0 && $sort_fasta_before->similarity <= $self->_min_similarity) {
 
             if ( $self->mafft == 1 ) {
                 my $mafft_obj = Bio::Roary::External::Mafft->new(
@@ -139,7 +140,7 @@ Bio::Roary::CommandLine::GeneAlignmentFromNucleotides - Take in a multifasta fil
 
 =head1 VERSION
 
-version 3.3.1
+version 3.3.2
 
 =head1 SYNOPSIS
 
